@@ -84,7 +84,7 @@
 #' \code{\link[stats]{binom.test}}
 #' @references Kuhn, M. (2008), ``Building predictive models in R using the
 #' caret package, '' \emph{Journal of Statistical Software},
-#' (\url{http://www.jstatsoft.org/article/view/v028i05/v28i05.pdf}).
+#' (\doi{10.18637/jss.v028.i05}).
 #'
 #' Altman, D.G., Bland, J.M. (1994) ``Diagnostic tests 1: sensitivity and
 #' specificity,'' \emph{British Medical Journal}, vol 308, 1552.
@@ -184,12 +184,27 @@ confusionMatrix.default <- function(data, reference,
   getFromNamespace("confusionMatrix.table", "caret")(classTable, positive, prevalence = prevalence, mode = mode)
 }
 
+#' @rdname confusionMatrix
+#' @method confusionMatrix matrix
+#' @importFrom utils getFromNamespace
+#' @export
+confusionMatrix.matrix <- function(data,
+                                   positive = NULL,
+                                   prevalence = NULL,
+                                   mode = "sens_spec",
+                                   ...) {
+  if (length(unique(dim(data))) != 1) {
+    stop("matrix must have equal dimensions")
+  }
+  classTable <- as.table(data, ...)
+  confusionMatrix(classTable, positive, prevalence = prevalence, mode = mode)
+}
+
 #' @rdname confusionMatrix
 #' @importFrom stats binom.test mcnemar.test
 #' @export
 confusionMatrix.table <- function(data, positive = NULL,
                                   prevalence = NULL, mode = "sens_spec", ...){
-  requireNamespaceQuietStop("e1071")
   if(!(mode %in% c("sens_spec", "prec_recall", "everything")))
     stop("`mode` should be either 'sens_spec', 'prec_recall', or 'everything'")
   if(length(dim(data)) != 2) stop("the table must have two dimensions")
